@@ -1,9 +1,9 @@
 package Music::ModalFunction;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Inspect Musical Modal Functions
+# ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0310';
+our $VERSION = '0.0311';
 
 use Moo;
 use strictures 2;
@@ -237,11 +237,11 @@ __END__
 
 =head1 NAME
 
-Music::ModalFunction - Inspect Musical Modal Functions
+Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0310
+version 0.0311
 
 =head1 SYNOPSIS
 
@@ -349,9 +349,9 @@ Create a new C<Music::ModalFunction> object.
 
 Ask the database a question about what chords are in what keys.
 
-Positional arguments:
+Constructor arguments:
 
-  ChordNote, Chord, KeyNote, Key, KeyFunction, KeyRoman
+  chord_note, chord, key_note, key, key_function, key_roman
 
 Here, B<ChordNote> and B<Chord> together are the named chord defined
 within the context of the B<KeyNote> and B<Key>. The chord's function
@@ -369,9 +369,9 @@ unbound variable is used.
 
 Ask the database a question about what chords share common keys.
 
-Positional arguments:
+Constructor arguments:
 
-  ChordNote, Chord, ModeNote, Mode, ModeFunction, ModeRoman, KeyNote, Key, KeyFunction, KeyRoman
+  chord_note, chord, mode_note, mode, mode_function, mode_roman, key_note, key, key_function, key_roman
 
 Here, B<ChordNote> and B<Chord> together are the named chord defined
 within the context of the B<ModeNote> and B<Mode>. The chord's
@@ -393,9 +393,9 @@ unbound variable is used.
 Ask the database a question about what Roman numeral functional chords
 share common keys.
 
-Positional arguments:
+Constructor arguments:
 
-  Mode, ModeRoman, Key, KeyRoman
+  mode, mode_roman, key, key_roman
 
 If defined, argument values will be bound to a variable. Otherwise an
 unbound variable is used.
